@@ -65,7 +65,7 @@ class NpbBench:
         target_file = os.path.expanduser('~/.local/tmp/NPB3.4-MPI.tar.gz')
         if not os.path.isfile(target_file):
             os.makedirs(os.path.expanduser('~/.local/tmp/'), exist_ok=True)
-            executor.local('wget https://www.nas.nasa.gov/assets/npb/NPB3.4.tar.gz -O %s' % target_file)
+            executor.local('wget https://www.nas.nasa.gov/assets/nas/npb/NPB3.4.tar.gz -O %s' % target_file)
         executor.local('tar xfC %s /tmp/' % target_file, shell=False)
         executor.local('cp /tmp/NPB3.4/NPB3.4-MPI/config/make.def.template /tmp/NPB3.4/NPB3.4-MPI/config/make.def')
         executor.local("sed -i 's/mpif90/mpif90 -fallow-argument-mismatch -fallow-invalid-boz/' /tmp/NPB3.4/NPB3.4-MPI/config/make.def")
