@@ -5,17 +5,18 @@ import os
 import json
 
 import platform 
-def get_g5k_target_metric():
-    cluster_name = platform.node().split('-')[0]
+def get_g5k_target_metric(cluster_name=None):
+    if cluster_name is None:
+        cluster_name = platform.node().split('-')[0]
 
     if cluster_name in ['grisou', 'graoully', 'grimoire',
-                        'grisou', 'gros', 'gruss', 'paravance']:
-        target_metric = 'pdu_outlet_power_watt'
-    elif cluster_name in ['troll', 'yeti', 'gemini', 'neowise',
+                        'gros', 'gruss', 'paravance']:
+        return 'pdu_outlet_power_watt'
+    if cluster_name in ['troll', 'yeti', 'gemini', 'neowise',
                           'orion', 'pyxis', 'sagittaire', 'taurus']:
-        target_metric = 'wattmetre_power_watt'
-    else:
-        target_metric = 'bmc_node_power_watt'
+        return 'wattmetre_power_watt'
+
+    return 'bmc_node_power_watt'
 
 class Power:
     'Monitoring using Kwollect on g5k'
